@@ -1,3 +1,9 @@
+"""
+Functional Group Factory Utilities
+==================================
+
+"""
+
 import rdkit.Chem.AllChem as rdkit
 
 
